# `pytesio`

`pytesio` contains python code to read and write data from pytesdaq and other TESSERACT code for TES detector related R&D and dark matter searches.

To install the most recent release of `pytesio`, type the following line into your command line

`pip install pytesio --upgrade`

To install the most recent development version of `pytesio`, clone this repo, then from the top-level directory of the repo, type the following line into your command line

`pip install .`

If using a shared Python installation, you may want to add the `--user` flag to the above line.
